@@ -19,5 +19,5 @@ def run():
     installer.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     run()
